# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimServiceProviderConfigAuthenticationScheme(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimServiceProviderConfigAuthenticationScheme - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'spec_uri': 'str',
            'documentation_uri': 'str',
            'type': 'str',
            'primary': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'spec_uri': 'specUri',
            'documentation_uri': 'documentationUri',
            'type': 'type',
            'primary': 'primary'
        }

        self._name = None
        self._description = None
        self._spec_uri = None
        self._documentation_uri = None
        self._type = None
        self._primary = None

    @property
    def name(self):
        """
        Gets the name of this ScimServiceProviderConfigAuthenticationScheme.
        The name of the authentication scheme, for example, HTTP Basic.

        :return: The name of this ScimServiceProviderConfigAuthenticationScheme.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScimServiceProviderConfigAuthenticationScheme.
        The name of the authentication scheme, for example, HTTP Basic.

        :param name: The name of this ScimServiceProviderConfigAuthenticationScheme.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ScimServiceProviderConfigAuthenticationScheme.
        The description of the authentication scheme.

        :return: The description of this ScimServiceProviderConfigAuthenticationScheme.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ScimServiceProviderConfigAuthenticationScheme.
        The description of the authentication scheme.

        :param description: The description of this ScimServiceProviderConfigAuthenticationScheme.
        :type: str
        """
        
        self._description = description

    @property
    def spec_uri(self):
        """
        Gets the spec_uri of this ScimServiceProviderConfigAuthenticationScheme.
        The HTTP-addressable URL that points to the authentication scheme's specification.

        :return: The spec_uri of this ScimServiceProviderConfigAuthenticationScheme.
        :rtype: str
        """
        return self._spec_uri

    @spec_uri.setter
    def spec_uri(self, spec_uri):
        """
        Sets the spec_uri of this ScimServiceProviderConfigAuthenticationScheme.
        The HTTP-addressable URL that points to the authentication scheme's specification.

        :param spec_uri: The spec_uri of this ScimServiceProviderConfigAuthenticationScheme.
        :type: str
        """
        
        self._spec_uri = spec_uri

    @property
    def documentation_uri(self):
        """
        Gets the documentation_uri of this ScimServiceProviderConfigAuthenticationScheme.
        The HTTP-addressable URL that points to the authentication scheme's usage documentation.

        :return: The documentation_uri of this ScimServiceProviderConfigAuthenticationScheme.
        :rtype: str
        """
        return self._documentation_uri

    @documentation_uri.setter
    def documentation_uri(self, documentation_uri):
        """
        Sets the documentation_uri of this ScimServiceProviderConfigAuthenticationScheme.
        The HTTP-addressable URL that points to the authentication scheme's usage documentation.

        :param documentation_uri: The documentation_uri of this ScimServiceProviderConfigAuthenticationScheme.
        :type: str
        """
        
        self._documentation_uri = documentation_uri

    @property
    def type(self):
        """
        Gets the type of this ScimServiceProviderConfigAuthenticationScheme.
        The type of authentication scheme.

        :return: The type of this ScimServiceProviderConfigAuthenticationScheme.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ScimServiceProviderConfigAuthenticationScheme.
        The type of authentication scheme.

        :param type: The type of this ScimServiceProviderConfigAuthenticationScheme.
        :type: str
        """
        allowed_values = ["oauth", "oauth2", "oauthbearertoken", "httpbasic", "httpdigest"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def primary(self):
        """
        Gets the primary of this ScimServiceProviderConfigAuthenticationScheme.
        Indicates whether this authentication scheme is the primary method of authentication.

        :return: The primary of this ScimServiceProviderConfigAuthenticationScheme.
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """
        Sets the primary of this ScimServiceProviderConfigAuthenticationScheme.
        Indicates whether this authentication scheme is the primary method of authentication.

        :param primary: The primary of this ScimServiceProviderConfigAuthenticationScheme.
        :type: bool
        """
        
        self._primary = primary

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class FacebookIntegration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacebookIntegration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'app_id': 'str',
            'page_id': 'str',
            'status': 'str',
            'recipient': 'DomainEntityRef',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'created_by': 'DomainEntityRef',
            'modified_by': 'DomainEntityRef',
            'version': 'int',
            'create_status': 'str',
            'create_error': 'ErrorBody',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'app_id': 'appId',
            'page_id': 'pageId',
            'status': 'status',
            'recipient': 'recipient',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'created_by': 'createdBy',
            'modified_by': 'modifiedBy',
            'version': 'version',
            'create_status': 'createStatus',
            'create_error': 'createError',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._app_id = None
        self._page_id = None
        self._status = None
        self._recipient = None
        self._date_created = None
        self._date_modified = None
        self._created_by = None
        self._modified_by = None
        self._version = None
        self._create_status = None
        self._create_error = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FacebookIntegration.
        A unique Integration Id.

        :return: The id of this FacebookIntegration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FacebookIntegration.
        A unique Integration Id.

        :param id: The id of this FacebookIntegration.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FacebookIntegration.
        The name of the Facebook Integration

        :return: The name of this FacebookIntegration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FacebookIntegration.
        The name of the Facebook Integration

        :param name: The name of this FacebookIntegration.
        :type: str
        """
        
        self._name = name

    @property
    def app_id(self):
        """
        Gets the app_id of this FacebookIntegration.
        The App Id from Facebook messenger

        :return: The app_id of this FacebookIntegration.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """
        Sets the app_id of this FacebookIntegration.
        The App Id from Facebook messenger

        :param app_id: The app_id of this FacebookIntegration.
        :type: str
        """
        
        self._app_id = app_id

    @property
    def page_id(self):
        """
        Gets the page_id of this FacebookIntegration.
        The Page Id from Facebook messenger

        :return: The page_id of this FacebookIntegration.
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """
        Sets the page_id of this FacebookIntegration.
        The Page Id from Facebook messenger

        :param page_id: The page_id of this FacebookIntegration.
        :type: str
        """
        
        self._page_id = page_id

    @property
    def status(self):
        """
        Gets the status of this FacebookIntegration.
        The status of the Facebook Integration

        :return: The status of this FacebookIntegration.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this FacebookIntegration.
        The status of the Facebook Integration

        :param status: The status of this FacebookIntegration.
        :type: str
        """
        
        self._status = status

    @property
    def recipient(self):
        """
        Gets the recipient of this FacebookIntegration.
        The recipient reference associated to the Facebook Integration. This recipient is used to associate a flow to an integration

        :return: The recipient of this FacebookIntegration.
        :rtype: DomainEntityRef
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """
        Sets the recipient of this FacebookIntegration.
        The recipient reference associated to the Facebook Integration. This recipient is used to associate a flow to an integration

        :param recipient: The recipient of this FacebookIntegration.
        :type: DomainEntityRef
        """
        
        self._recipient = recipient

    @property
    def date_created(self):
        """
        Gets the date_created of this FacebookIntegration.
        Date this Integration was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this FacebookIntegration.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this FacebookIntegration.
        Date this Integration was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this FacebookIntegration.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this FacebookIntegration.
        Date this Integration was modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this FacebookIntegration.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this FacebookIntegration.
        Date this Integration was modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this FacebookIntegration.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def created_by(self):
        """
        Gets the created_by of this FacebookIntegration.
        User reference that created this Integration

        :return: The created_by of this FacebookIntegration.
        :rtype: DomainEntityRef
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this FacebookIntegration.
        User reference that created this Integration

        :param created_by: The created_by of this FacebookIntegration.
        :type: DomainEntityRef
        """
        
        self._created_by = created_by

    @property
    def modified_by(self):
        """
        Gets the modified_by of this FacebookIntegration.
        User reference that last modified this Integration

        :return: The modified_by of this FacebookIntegration.
        :rtype: DomainEntityRef
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this FacebookIntegration.
        User reference that last modified this Integration

        :param modified_by: The modified_by of this FacebookIntegration.
        :type: DomainEntityRef
        """
        
        self._modified_by = modified_by

    @property
    def version(self):
        """
        Gets the version of this FacebookIntegration.
        Version number required for updates.

        :return: The version of this FacebookIntegration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this FacebookIntegration.
        Version number required for updates.

        :param version: The version of this FacebookIntegration.
        :type: int
        """
        
        self._version = version

    @property
    def create_status(self):
        """
        Gets the create_status of this FacebookIntegration.
        Status of asynchronous create operation

        :return: The create_status of this FacebookIntegration.
        :rtype: str
        """
        return self._create_status

    @create_status.setter
    def create_status(self, create_status):
        """
        Sets the create_status of this FacebookIntegration.
        Status of asynchronous create operation

        :param create_status: The create_status of this FacebookIntegration.
        :type: str
        """
        allowed_values = ["Initiated", "Completed", "Error"]
        if create_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for create_status -> " + create_status)
            self._create_status = "outdated_sdk_version"
        else:
            self._create_status = create_status

    @property
    def create_error(self):
        """
        Gets the create_error of this FacebookIntegration.
        Error information returned, if createStatus is set to Error

        :return: The create_error of this FacebookIntegration.
        :rtype: ErrorBody
        """
        return self._create_error

    @create_error.setter
    def create_error(self, create_error):
        """
        Sets the create_error of this FacebookIntegration.
        Error information returned, if createStatus is set to Error

        :param create_error: The create_error of this FacebookIntegration.
        :type: ErrorBody
        """
        
        self._create_error = create_error

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FacebookIntegration.
        The URI for this object

        :return: The self_uri of this FacebookIntegration.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FacebookIntegration.
        The URI for this object

        :param self_uri: The self_uri of this FacebookIntegration.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AsyncQueryStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AsyncQueryStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'error_message': 'str',
            'expiration_date': 'datetime',
            'submission_date': 'datetime',
            'completion_date': 'datetime'
        }

        self.attribute_map = {
            'state': 'state',
            'error_message': 'errorMessage',
            'expiration_date': 'expirationDate',
            'submission_date': 'submissionDate',
            'completion_date': 'completionDate'
        }

        self._state = None
        self._error_message = None
        self._expiration_date = None
        self._submission_date = None
        self._completion_date = None

    @property
    def state(self):
        """
        Gets the state of this AsyncQueryStatus.
        The current state of the asynchronous query

        :return: The state of this AsyncQueryStatus.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this AsyncQueryStatus.
        The current state of the asynchronous query

        :param state: The state of this AsyncQueryStatus.
        :type: str
        """
        allowed_values = ["QUEUED", "PENDING", "FAILED", "CANCELLED", "FULFILLED", "EXPIRED"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def error_message(self):
        """
        Gets the error_message of this AsyncQueryStatus.
        The error associated with the current query, if the state is FAILED

        :return: The error_message of this AsyncQueryStatus.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this AsyncQueryStatus.
        The error associated with the current query, if the state is FAILED

        :param error_message: The error_message of this AsyncQueryStatus.
        :type: str
        """
        
        self._error_message = error_message

    @property
    def expiration_date(self):
        """
        Gets the expiration_date of this AsyncQueryStatus.
        The time at which results for this query will expire. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The expiration_date of this AsyncQueryStatus.
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """
        Sets the expiration_date of this AsyncQueryStatus.
        The time at which results for this query will expire. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param expiration_date: The expiration_date of this AsyncQueryStatus.
        :type: datetime
        """
        
        self._expiration_date = expiration_date

    @property
    def submission_date(self):
        """
        Gets the submission_date of this AsyncQueryStatus.
        The time at which the query was submitted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The submission_date of this AsyncQueryStatus.
        :rtype: datetime
        """
        return self._submission_date

    @submission_date.setter
    def submission_date(self, submission_date):
        """
        Sets the submission_date of this AsyncQueryStatus.
        The time at which the query was submitted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param submission_date: The submission_date of this AsyncQueryStatus.
        :type: datetime
        """
        
        self._submission_date = submission_date

    @property
    def completion_date(self):
        """
        Gets the completion_date of this AsyncQueryStatus.
        The time at which the query completed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The completion_date of this AsyncQueryStatus.
        :rtype: datetime
        """
        return self._completion_date

    @completion_date.setter
    def completion_date(self, completion_date):
        """
        Sets the completion_date of this AsyncQueryStatus.
        The time at which the query completed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param completion_date: The completion_date of this AsyncQueryStatus.
        :type: datetime
        """
        
        self._completion_date = completion_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class PatchSurveyQuestion(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PatchSurveyQuestion - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'label': 'str',
            'customer_property': 'str',
            'choices': 'list[str]',
            'is_mandatory': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'label': 'label',
            'customer_property': 'customerProperty',
            'choices': 'choices',
            'is_mandatory': 'isMandatory'
        }

        self._type = None
        self._label = None
        self._customer_property = None
        self._choices = None
        self._is_mandatory = None

    @property
    def type(self):
        """
        Gets the type of this PatchSurveyQuestion.
        Type of survey question.

        :return: The type of this PatchSurveyQuestion.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PatchSurveyQuestion.
        Type of survey question.

        :param type: The type of this PatchSurveyQuestion.
        :type: str
        """
        allowed_values = ["text", "hidden", "select", "checkbox", "textarea"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def label(self):
        """
        Gets the label of this PatchSurveyQuestion.
        Label of question.

        :return: The label of this PatchSurveyQuestion.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this PatchSurveyQuestion.
        Label of question.

        :param label: The label of this PatchSurveyQuestion.
        :type: str
        """
        
        self._label = label

    @property
    def customer_property(self):
        """
        Gets the customer_property of this PatchSurveyQuestion.
        The customer property that the answer maps to.

        :return: The customer_property of this PatchSurveyQuestion.
        :rtype: str
        """
        return self._customer_property

    @customer_property.setter
    def customer_property(self, customer_property):
        """
        Sets the customer_property of this PatchSurveyQuestion.
        The customer property that the answer maps to.

        :param customer_property: The customer_property of this PatchSurveyQuestion.
        :type: str
        """
        allowed_values = ["givenName", "familyName", "email", "phone", "gender", "companyName"]
        if customer_property.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for customer_property -> " + customer_property)
            self._customer_property = "outdated_sdk_version"
        else:
            self._customer_property = customer_property

    @property
    def choices(self):
        """
        Gets the choices of this PatchSurveyQuestion.
        Choices available to user.

        :return: The choices of this PatchSurveyQuestion.
        :rtype: list[str]
        """
        return self._choices

    @choices.setter
    def choices(self, choices):
        """
        Sets the choices of this PatchSurveyQuestion.
        Choices available to user.

        :param choices: The choices of this PatchSurveyQuestion.
        :type: list[str]
        """
        
        self._choices = choices

    @property
    def is_mandatory(self):
        """
        Gets the is_mandatory of this PatchSurveyQuestion.
        Whether answering this question is mandatory.

        :return: The is_mandatory of this PatchSurveyQuestion.
        :rtype: bool
        """
        return self._is_mandatory

    @is_mandatory.setter
    def is_mandatory(self, is_mandatory):
        """
        Sets the is_mandatory of this PatchSurveyQuestion.
        Whether answering this question is mandatory.

        :param is_mandatory: The is_mandatory of this PatchSurveyQuestion.
        :type: bool
        """
        
        self._is_mandatory = is_mandatory

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class RoutePathRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RoutePathRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'queue_id': 'str',
            'media_type': 'str',
            'language_id': 'str',
            'skill_ids': 'list[str]',
            'source_planning_group': 'SourcePlanningGroupRequest'
        }

        self.attribute_map = {
            'queue_id': 'queueId',
            'media_type': 'mediaType',
            'language_id': 'languageId',
            'skill_ids': 'skillIds',
            'source_planning_group': 'sourcePlanningGroup'
        }

        self._queue_id = None
        self._media_type = None
        self._language_id = None
        self._skill_ids = None
        self._source_planning_group = None

    @property
    def queue_id(self):
        """
        Gets the queue_id of this RoutePathRequest.
        The ID of the queue to associate with the route path

        :return: The queue_id of this RoutePathRequest.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this RoutePathRequest.
        The ID of the queue to associate with the route path

        :param queue_id: The queue_id of this RoutePathRequest.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def media_type(self):
        """
        Gets the media_type of this RoutePathRequest.
        The media type of the given queue to associate with the route path

        :return: The media_type of this RoutePathRequest.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this RoutePathRequest.
        The media type of the given queue to associate with the route path

        :param media_type: The media_type of this RoutePathRequest.
        :type: str
        """
        allowed_values = ["Voice", "Chat", "Email", "Callback", "Message"]
        if media_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for media_type -> " + media_type)
            self._media_type = "outdated_sdk_version"
        else:
            self._media_type = media_type

    @property
    def language_id(self):
        """
        Gets the language_id of this RoutePathRequest.
        The ID of the language to associate with the route path

        :return: The language_id of this RoutePathRequest.
        :rtype: str
        """
        return self._language_id

    @language_id.setter
    def language_id(self, language_id):
        """
        Sets the language_id of this RoutePathRequest.
        The ID of the language to associate with the route path

        :param language_id: The language_id of this RoutePathRequest.
        :type: str
        """
        
        self._language_id = language_id

    @property
    def skill_ids(self):
        """
        Gets the skill_ids of this RoutePathRequest.
        The set of skill IDs to associate with the route path

        :return: The skill_ids of this RoutePathRequest.
        :rtype: list[str]
        """
        return self._skill_ids

    @skill_ids.setter
    def skill_ids(self, skill_ids):
        """
        Sets the skill_ids of this RoutePathRequest.
        The set of skill IDs to associate with the route path

        :param skill_ids: The skill_ids of this RoutePathRequest.
        :type: list[str]
        """
        
        self._skill_ids = skill_ids

    @property
    def source_planning_group(self):
        """
        Gets the source_planning_group of this RoutePathRequest.
        The planning group from which to copy route paths

        :return: The source_planning_group of this RoutePathRequest.
        :rtype: SourcePlanningGroupRequest
        """
        return self._source_planning_group

    @source_planning_group.setter
    def source_planning_group(self, source_planning_group):
        """
        Sets the source_planning_group of this RoutePathRequest.
        The planning group from which to copy route paths

        :param source_planning_group: The source_planning_group of this RoutePathRequest.
        :type: SourcePlanningGroupRequest
        """
        
        self._source_planning_group = source_planning_group

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmHistoricalAdherenceQueryForUsers(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmHistoricalAdherenceQueryForUsers - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_date': 'datetime',
            'end_date': 'datetime',
            'time_zone': 'str',
            'user_ids': 'list[str]',
            'include_exceptions': 'bool'
        }

        self.attribute_map = {
            'start_date': 'startDate',
            'end_date': 'endDate',
            'time_zone': 'timeZone',
            'user_ids': 'userIds',
            'include_exceptions': 'includeExceptions'
        }

        self._start_date = None
        self._end_date = None
        self._time_zone = None
        self._user_ids = None
        self._include_exceptions = None

    @property
    def start_date(self):
        """
        Gets the start_date of this WfmHistoricalAdherenceQueryForUsers.
        Beginning of the date range to query in ISO-8601 format

        :return: The start_date of this WfmHistoricalAdherenceQueryForUsers.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this WfmHistoricalAdherenceQueryForUsers.
        Beginning of the date range to query in ISO-8601 format

        :param start_date: The start_date of this WfmHistoricalAdherenceQueryForUsers.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this WfmHistoricalAdherenceQueryForUsers.
        End of the date range to query in ISO-8601 format. If it is not set, end date will be set to current time

        :return: The end_date of this WfmHistoricalAdherenceQueryForUsers.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this WfmHistoricalAdherenceQueryForUsers.
        End of the date range to query in ISO-8601 format. If it is not set, end date will be set to current time

        :param end_date: The end_date of this WfmHistoricalAdherenceQueryForUsers.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def time_zone(self):
        """
        Gets the time_zone of this WfmHistoricalAdherenceQueryForUsers.
        The time zone to use for returned results in olson format. If it is not set, the business unit time zone will be used to compute adherence

        :return: The time_zone of this WfmHistoricalAdherenceQueryForUsers.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this WfmHistoricalAdherenceQueryForUsers.
        The time zone to use for returned results in olson format. If it is not set, the business unit time zone will be used to compute adherence

        :param time_zone: The time_zone of this WfmHistoricalAdherenceQueryForUsers.
        :type: str
        """
        
        self._time_zone = time_zone

    @property
    def user_ids(self):
        """
        Gets the user_ids of this WfmHistoricalAdherenceQueryForUsers.
        The userIds to report on

        :return: The user_ids of this WfmHistoricalAdherenceQueryForUsers.
        :rtype: list[str]
        """
        return self._user_ids

    @user_ids.setter
    def user_ids(self, user_ids):
        """
        Sets the user_ids of this WfmHistoricalAdherenceQueryForUsers.
        The userIds to report on

        :param user_ids: The user_ids of this WfmHistoricalAdherenceQueryForUsers.
        :type: list[str]
        """
        
        self._user_ids = user_ids

    @property
    def include_exceptions(self):
        """
        Gets the include_exceptions of this WfmHistoricalAdherenceQueryForUsers.
        Whether user exceptions should be returned as part of the results

        :return: The include_exceptions of this WfmHistoricalAdherenceQueryForUsers.
        :rtype: bool
        """
        return self._include_exceptions

    @include_exceptions.setter
    def include_exceptions(self, include_exceptions):
        """
        Sets the include_exceptions of this WfmHistoricalAdherenceQueryForUsers.
        Whether user exceptions should be returned as part of the results

        :param include_exceptions: The include_exceptions of this WfmHistoricalAdherenceQueryForUsers.
        :type: bool
        """
        
        self._include_exceptions = include_exceptions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class GuestMemberInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        GuestMemberInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'display_name': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'email': 'str',
            'phone_number': 'str',
            'avatar_image_url': 'str',
            'custom_fields': 'dict(str, str)'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'first_name': 'firstName',
            'last_name': 'lastName',
            'email': 'email',
            'phone_number': 'phoneNumber',
            'avatar_image_url': 'avatarImageUrl',
            'custom_fields': 'customFields'
        }

        self._display_name = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._phone_number = None
        self._avatar_image_url = None
        self._custom_fields = None

    @property
    def display_name(self):
        """
        Gets the display_name of this GuestMemberInfo.
        The display name to use for the guest member in the conversation.

        :return: The display_name of this GuestMemberInfo.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this GuestMemberInfo.
        The display name to use for the guest member in the conversation.

        :param display_name: The display_name of this GuestMemberInfo.
        :type: str
        """
        
        self._display_name = display_name

    @property
    def first_name(self):
        """
        Gets the first_name of this GuestMemberInfo.
        The first name to use for the guest member in the conversation.

        :return: The first_name of this GuestMemberInfo.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this GuestMemberInfo.
        The first name to use for the guest member in the conversation.

        :param first_name: The first_name of this GuestMemberInfo.
        :type: str
        """
        
        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this GuestMemberInfo.
        The last name to use for the guest member in the conversation.

        :return: The last_name of this GuestMemberInfo.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this GuestMemberInfo.
        The last name to use for the guest member in the conversation.

        :param last_name: The last_name of this GuestMemberInfo.
        :type: str
        """
        
        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this GuestMemberInfo.
        The email address to use for the guest member in the conversation.

        :return: The email of this GuestMemberInfo.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this GuestMemberInfo.
        The email address to use for the guest member in the conversation.

        :param email: The email of this GuestMemberInfo.
        :type: str
        """
        
        self._email = email

    @property
    def phone_number(self):
        """
        Gets the phone_number of this GuestMemberInfo.
        The phone number to use for the guest member in the conversation.

        :return: The phone_number of this GuestMemberInfo.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this GuestMemberInfo.
        The phone number to use for the guest member in the conversation.

        :param phone_number: The phone_number of this GuestMemberInfo.
        :type: str
        """
        
        self._phone_number = phone_number

    @property
    def avatar_image_url(self):
        """
        Gets the avatar_image_url of this GuestMemberInfo.
        The URL to the avatar image to use for the guest member in the conversation, if any.

        :return: The avatar_image_url of this GuestMemberInfo.
        :rtype: str
        """
        return self._avatar_image_url

    @avatar_image_url.setter
    def avatar_image_url(self, avatar_image_url):
        """
        Sets the avatar_image_url of this GuestMemberInfo.
        The URL to the avatar image to use for the guest member in the conversation, if any.

        :param avatar_image_url: The avatar_image_url of this GuestMemberInfo.
        :type: str
        """
        
        self._avatar_image_url = avatar_image_url

    @property
    def custom_fields(self):
        """
        Gets the custom_fields of this GuestMemberInfo.
        Any custom fields of information, in key-value format, to attach to the guest member in the conversation.

        :return: The custom_fields of this GuestMemberInfo.
        :rtype: dict(str, str)
        """
        return self._custom_fields

    @custom_fields.setter
    def custom_fields(self, custom_fields):
        """
        Sets the custom_fields of this GuestMemberInfo.
        Any custom fields of information, in key-value format, to attach to the guest member in the conversation.

        :param custom_fields: The custom_fields of this GuestMemberInfo.
        :type: dict(str, str)
        """
        
        self._custom_fields = custom_fields

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateWebChatRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateWebChatRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'queue_id': 'str',
            'provider': 'str',
            'skill_ids': 'list[str]',
            'language_id': 'str',
            'priority': 'int',
            'attributes': 'dict(str, str)',
            'customer_name': 'str'
        }

        self.attribute_map = {
            'queue_id': 'queueId',
            'provider': 'provider',
            'skill_ids': 'skillIds',
            'language_id': 'languageId',
            'priority': 'priority',
            'attributes': 'attributes',
            'customer_name': 'customerName'
        }

        self._queue_id = None
        self._provider = None
        self._skill_ids = None
        self._language_id = None
        self._priority = None
        self._attributes = None
        self._customer_name = None

    @property
    def queue_id(self):
        """
        Gets the queue_id of this CreateWebChatRequest.
        The ID of the queue to use for routing the chat conversation.

        :return: The queue_id of this CreateWebChatRequest.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this CreateWebChatRequest.
        The ID of the queue to use for routing the chat conversation.

        :param queue_id: The queue_id of this CreateWebChatRequest.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def provider(self):
        """
        Gets the provider of this CreateWebChatRequest.
        The name of the provider that is sourcing the web chat.

        :return: The provider of this CreateWebChatRequest.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this CreateWebChatRequest.
        The name of the provider that is sourcing the web chat.

        :param provider: The provider of this CreateWebChatRequest.
        :type: str
        """
        
        self._provider = provider

    @property
    def skill_ids(self):
        """
        Gets the skill_ids of this CreateWebChatRequest.
        The list of skill ID's to use for routing.

        :return: The skill_ids of this CreateWebChatRequest.
        :rtype: list[str]
        """
        return self._skill_ids

    @skill_ids.setter
    def skill_ids(self, skill_ids):
        """
        Sets the skill_ids of this CreateWebChatRequest.
        The list of skill ID's to use for routing.

        :param skill_ids: The skill_ids of this CreateWebChatRequest.
        :type: list[str]
        """
        
        self._skill_ids = skill_ids

    @property
    def language_id(self):
        """
        Gets the language_id of this CreateWebChatRequest.
        The ID of the langauge to use for routing.

        :return: The language_id of this CreateWebChatRequest.
        :rtype: str
        """
        return self._language_id

    @language_id.setter
    def language_id(self, language_id):
        """
        Sets the language_id of this CreateWebChatRequest.
        The ID of the langauge to use for routing.

        :param language_id: The language_id of this CreateWebChatRequest.
        :type: str
        """
        
        self._language_id = language_id

    @property
    def priority(self):
        """
        Gets the priority of this CreateWebChatRequest.
        The priority to assign to the conversation for routing.

        :return: The priority of this CreateWebChatRequest.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this CreateWebChatRequest.
        The priority to assign to the conversation for routing.

        :param priority: The priority of this CreateWebChatRequest.
        :type: int
        """
        
        self._priority = priority

    @property
    def attributes(self):
        """
        Gets the attributes of this CreateWebChatRequest.
        The list of attributes to associate with the customer participant.

        :return: The attributes of this CreateWebChatRequest.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this CreateWebChatRequest.
        The list of attributes to associate with the customer participant.

        :param attributes: The attributes of this CreateWebChatRequest.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def customer_name(self):
        """
        Gets the customer_name of this CreateWebChatRequest.
        The name of the customer participating in the web chat.

        :return: The customer_name of this CreateWebChatRequest.
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """
        Sets the customer_name of this CreateWebChatRequest.
        The name of the customer participating in the web chat.

        :param customer_name: The customer_name of this CreateWebChatRequest.
        :type: str
        """
        
        self._customer_name = customer_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EdgeMetricsNetwork(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeMetricsNetwork - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'ifname': 'str',
            'sent_bytes_per_sec': 'int',
            'received_bytes_per_sec': 'int',
            'bandwidth_bits_per_sec': 'float',
            'utilization_pct': 'float'
        }

        self.attribute_map = {
            'ifname': 'ifname',
            'sent_bytes_per_sec': 'sentBytesPerSec',
            'received_bytes_per_sec': 'receivedBytesPerSec',
            'bandwidth_bits_per_sec': 'bandwidthBitsPerSec',
            'utilization_pct': 'utilizationPct'
        }

        self._ifname = None
        self._sent_bytes_per_sec = None
        self._received_bytes_per_sec = None
        self._bandwidth_bits_per_sec = None
        self._utilization_pct = None

    @property
    def ifname(self):
        """
        Gets the ifname of this EdgeMetricsNetwork.
        Identifier for the network adapter.

        :return: The ifname of this EdgeMetricsNetwork.
        :rtype: str
        """
        return self._ifname

    @ifname.setter
    def ifname(self, ifname):
        """
        Sets the ifname of this EdgeMetricsNetwork.
        Identifier for the network adapter.

        :param ifname: The ifname of this EdgeMetricsNetwork.
        :type: str
        """
        
        self._ifname = ifname

    @property
    def sent_bytes_per_sec(self):
        """
        Gets the sent_bytes_per_sec of this EdgeMetricsNetwork.
        Number of byes sent per second.

        :return: The sent_bytes_per_sec of this EdgeMetricsNetwork.
        :rtype: int
        """
        return self._sent_bytes_per_sec

    @sent_bytes_per_sec.setter
    def sent_bytes_per_sec(self, sent_bytes_per_sec):
        """
        Sets the sent_bytes_per_sec of this EdgeMetricsNetwork.
        Number of byes sent per second.

        :param sent_bytes_per_sec: The sent_bytes_per_sec of this EdgeMetricsNetwork.
        :type: int
        """
        
        self._sent_bytes_per_sec = sent_bytes_per_sec

    @property
    def received_bytes_per_sec(self):
        """
        Gets the received_bytes_per_sec of this EdgeMetricsNetwork.
        Number of byes received per second.

        :return: The received_bytes_per_sec of this EdgeMetricsNetwork.
        :rtype: int
        """
        return self._received_bytes_per_sec

    @received_bytes_per_sec.setter
    def received_bytes_per_sec(self, received_bytes_per_sec):
        """
        Sets the received_bytes_per_sec of this EdgeMetricsNetwork.
        Number of byes received per second.

        :param received_bytes_per_sec: The received_bytes_per_sec of this EdgeMetricsNetwork.
        :type: int
        """
        
        self._received_bytes_per_sec = received_bytes_per_sec

    @property
    def bandwidth_bits_per_sec(self):
        """
        Gets the bandwidth_bits_per_sec of this EdgeMetricsNetwork.
        Total bandwidth of the adapter in bits per second.

        :return: The bandwidth_bits_per_sec of this EdgeMetricsNetwork.
        :rtype: float
        """
        return self._bandwidth_bits_per_sec

    @bandwidth_bits_per_sec.setter
    def bandwidth_bits_per_sec(self, bandwidth_bits_per_sec):
        """
        Sets the bandwidth_bits_per_sec of this EdgeMetricsNetwork.
        Total bandwidth of the adapter in bits per second.

        :param bandwidth_bits_per_sec: The bandwidth_bits_per_sec of this EdgeMetricsNetwork.
        :type: float
        """
        
        self._bandwidth_bits_per_sec = bandwidth_bits_per_sec

    @property
    def utilization_pct(self):
        """
        Gets the utilization_pct of this EdgeMetricsNetwork.
        Percent utilization of the network adapter.

        :return: The utilization_pct of this EdgeMetricsNetwork.
        :rtype: float
        """
        return self._utilization_pct

    @utilization_pct.setter
    def utilization_pct(self, utilization_pct):
        """
        Sets the utilization_pct of this EdgeMetricsNetwork.
        Percent utilization of the network adapter.

        :param utilization_pct: The utilization_pct of this EdgeMetricsNetwork.
        :type: float
        """
        
        self._utilization_pct = utilization_pct

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Location(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Location - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'floorplan_id': 'str',
            'coordinates': 'dict(str, float)',
            'notes': 'str',
            'location_definition': 'LocationDefinition'
        }

        self.attribute_map = {
            'id': 'id',
            'floorplan_id': 'floorplanId',
            'coordinates': 'coordinates',
            'notes': 'notes',
            'location_definition': 'locationDefinition'
        }

        self._id = None
        self._floorplan_id = None
        self._coordinates = None
        self._notes = None
        self._location_definition = None

    @property
    def id(self):
        """
        Gets the id of this Location.
        Unique identifier for the location

        :return: The id of this Location.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Location.
        Unique identifier for the location

        :param id: The id of this Location.
        :type: str
        """
        
        self._id = id

    @property
    def floorplan_id(self):
        """
        Gets the floorplan_id of this Location.
        Unique identifier for the location floorplan image

        :return: The floorplan_id of this Location.
        :rtype: str
        """
        return self._floorplan_id

    @floorplan_id.setter
    def floorplan_id(self, floorplan_id):
        """
        Sets the floorplan_id of this Location.
        Unique identifier for the location floorplan image

        :param floorplan_id: The floorplan_id of this Location.
        :type: str
        """
        
        self._floorplan_id = floorplan_id

    @property
    def coordinates(self):
        """
        Gets the coordinates of this Location.
        Users coordinates on the floorplan. Only used when floorplanImage is set

        :return: The coordinates of this Location.
        :rtype: dict(str, float)
        """
        return self._coordinates

    @coordinates.setter
    def coordinates(self, coordinates):
        """
        Sets the coordinates of this Location.
        Users coordinates on the floorplan. Only used when floorplanImage is set

        :param coordinates: The coordinates of this Location.
        :type: dict(str, float)
        """
        
        self._coordinates = coordinates

    @property
    def notes(self):
        """
        Gets the notes of this Location.
        Optional description on the users location

        :return: The notes of this Location.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this Location.
        Optional description on the users location

        :param notes: The notes of this Location.
        :type: str
        """
        
        self._notes = notes

    @property
    def location_definition(self):
        """
        Gets the location_definition of this Location.


        :return: The location_definition of this Location.
        :rtype: LocationDefinition
        """
        return self._location_definition

    @location_definition.setter
    def location_definition(self, location_definition):
        """
        Sets the location_definition of this Location.


        :param location_definition: The location_definition of this Location.
        :type: LocationDefinition
        """
        
        self._location_definition = location_definition

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class JourneyPattern(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        JourneyPattern - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'criteria': 'list[Criteria]',
            'count': 'int',
            'stream_type': 'str',
            'session_type': 'str',
            'event_name': 'str'
        }

        self.attribute_map = {
            'criteria': 'criteria',
            'count': 'count',
            'stream_type': 'streamType',
            'session_type': 'sessionType',
            'event_name': 'eventName'
        }

        self._criteria = None
        self._count = None
        self._stream_type = None
        self._session_type = None
        self._event_name = None

    @property
    def criteria(self):
        """
        Gets the criteria of this JourneyPattern.
        A list of one or more criteria to satisfy.

        :return: The criteria of this JourneyPattern.
        :rtype: list[Criteria]
        """
        return self._criteria

    @criteria.setter
    def criteria(self, criteria):
        """
        Sets the criteria of this JourneyPattern.
        A list of one or more criteria to satisfy.

        :param criteria: The criteria of this JourneyPattern.
        :type: list[Criteria]
        """
        
        self._criteria = criteria

    @property
    def count(self):
        """
        Gets the count of this JourneyPattern.
        The number of times the pattern must match.

        :return: The count of this JourneyPattern.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this JourneyPattern.
        The number of times the pattern must match.

        :param count: The count of this JourneyPattern.
        :type: int
        """
        
        self._count = count

    @property
    def stream_type(self):
        """
        Gets the stream_type of this JourneyPattern.
        The stream type for which this pattern can be matched on.

        :return: The stream_type of this JourneyPattern.
        :rtype: str
        """
        return self._stream_type

    @stream_type.setter
    def stream_type(self, stream_type):
        """
        Sets the stream_type of this JourneyPattern.
        The stream type for which this pattern can be matched on.

        :param stream_type: The stream_type of this JourneyPattern.
        :type: str
        """
        allowed_values = ["Web", "Custom", "Conversation"]
        if stream_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for stream_type -> " + stream_type)
            self._stream_type = "outdated_sdk_version"
        else:
            self._stream_type = stream_type

    @property
    def session_type(self):
        """
        Gets the session_type of this JourneyPattern.
        The session type for which this pattern can be matched on.

        :return: The session_type of this JourneyPattern.
        :rtype: str
        """
        return self._session_type

    @session_type.setter
    def session_type(self, session_type):
        """
        Sets the session_type of this JourneyPattern.
        The session type for which this pattern can be matched on.

        :param session_type: The session_type of this JourneyPattern.
        :type: str
        """
        
        self._session_type = session_type

    @property
    def event_name(self):
        """
        Gets the event_name of this JourneyPattern.
        The name of the event for which this pattern can be matched on.

        :return: The event_name of this JourneyPattern.
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """
        Sets the event_name of this JourneyPattern.
        The name of the event for which this pattern can be matched on.

        :param event_name: The event_name of this JourneyPattern.
        :type: str
        """
        
        self._event_name = event_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from enum import Enum


class PureCloudRegionHosts(Enum):
    us_east_1 = "https://api.mypurecloud.com"
    eu_west_1 = "https://api.mypurecloud.ie"
    ap_southeast_2 = "https://api.mypurecloud.com.au"
    ap_northeast_1 = "https://api.mypurecloud.jp"
    eu_central_1 = "https://api.mypurecloud.de"
    us_west_2 = "https://api.usw2.pure.cloud"
    ca_central_1 = "https://api.cac1.pure.cloud"
    ap_northeast_2 = "https://api.apne2.pure.cloud"
    eu_west_2 = "https://api.euw2.pure.cloud"

    def __init__(self, apihost):
        self.apihost = apihost

    def get_api_host(self):
        return self.apihost






# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateAdminTimeOffRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateAdminTimeOffRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status': 'str',
            'users': 'list[UserReference]',
            'activity_code_id': 'str',
            'notes': 'str',
            'full_day_management_unit_dates': 'list[str]',
            'partial_day_start_date_times': 'list[datetime]',
            'daily_duration_minutes': 'int'
        }

        self.attribute_map = {
            'status': 'status',
            'users': 'users',
            'activity_code_id': 'activityCodeId',
            'notes': 'notes',
            'full_day_management_unit_dates': 'fullDayManagementUnitDates',
            'partial_day_start_date_times': 'partialDayStartDateTimes',
            'daily_duration_minutes': 'dailyDurationMinutes'
        }

        self._status = None
        self._users = None
        self._activity_code_id = None
        self._notes = None
        self._full_day_management_unit_dates = None
        self._partial_day_start_date_times = None
        self._daily_duration_minutes = None

    @property
    def status(self):
        """
        Gets the status of this CreateAdminTimeOffRequest.
        The status of this time off request

        :return: The status of this CreateAdminTimeOffRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this CreateAdminTimeOffRequest.
        The status of this time off request

        :param status: The status of this CreateAdminTimeOffRequest.
        :type: str
        """
        allowed_values = ["PENDING", "APPROVED"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def users(self):
        """
        Gets the users of this CreateAdminTimeOffRequest.
        A set of IDs for users to associate with this time off request

        :return: The users of this CreateAdminTimeOffRequest.
        :rtype: list[UserReference]
        """
        return self._users

    @users.setter
    def users(self, users):
        """
        Sets the users of this CreateAdminTimeOffRequest.
        A set of IDs for users to associate with this time off request

        :param users: The users of this CreateAdminTimeOffRequest.
        :type: list[UserReference]
        """
        
        self._users = users

    @property
    def activity_code_id(self):
        """
        Gets the activity_code_id of this CreateAdminTimeOffRequest.
        The ID of the activity code associated with this time off request. Activity code must be of the TimeOff category

        :return: The activity_code_id of this CreateAdminTimeOffRequest.
        :rtype: str
        """
        return self._activity_code_id

    @activity_code_id.setter
    def activity_code_id(self, activity_code_id):
        """
        Sets the activity_code_id of this CreateAdminTimeOffRequest.
        The ID of the activity code associated with this time off request. Activity code must be of the TimeOff category

        :param activity_code_id: The activity_code_id of this CreateAdminTimeOffRequest.
        :type: str
        """
        
        self._activity_code_id = activity_code_id

    @property
    def notes(self):
        """
        Gets the notes of this CreateAdminTimeOffRequest.
        Notes about the time off request

        :return: The notes of this CreateAdminTimeOffRequest.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this CreateAdminTimeOffRequest.
        Notes about the time off request

        :param notes: The notes of this CreateAdminTimeOffRequest.
        :type: str
        """
        
        self._notes = notes

    @property
    def full_day_management_unit_dates(self):
        """
        Gets the full_day_management_unit_dates of this CreateAdminTimeOffRequest.
        A set of dates in yyyy-MM-dd format.  Should be interpreted in the management unit's configured time zone.

        :return: The full_day_management_unit_dates of this CreateAdminTimeOffRequest.
        :rtype: list[str]
        """
        return self._full_day_management_unit_dates

    @full_day_management_unit_dates.setter
    def full_day_management_unit_dates(self, full_day_management_unit_dates):
        """
        Sets the full_day_management_unit_dates of this CreateAdminTimeOffRequest.
        A set of dates in yyyy-MM-dd format.  Should be interpreted in the management unit's configured time zone.

        :param full_day_management_unit_dates: The full_day_management_unit_dates of this CreateAdminTimeOffRequest.
        :type: list[str]
        """
        
        self._full_day_management_unit_dates = full_day_management_unit_dates

    @property
    def partial_day_start_date_times(self):
        """
        Gets the partial_day_start_date_times of this CreateAdminTimeOffRequest.
        A set of start date-times in ISO-8601 format for partial day requests.

        :return: The partial_day_start_date_times of this CreateAdminTimeOffRequest.
        :rtype: list[datetime]
        """
        return self._partial_day_start_date_times

    @partial_day_start_date_times.setter
    def partial_day_start_date_times(self, partial_day_start_date_times):
        """
        Sets the partial_day_start_date_times of this CreateAdminTimeOffRequest.
        A set of start date-times in ISO-8601 format for partial day requests.

        :param partial_day_start_date_times: The partial_day_start_date_times of this CreateAdminTimeOffRequest.
        :type: list[datetime]
        """
        
        self._partial_day_start_date_times = partial_day_start_date_times

    @property
    def daily_duration_minutes(self):
        """
        Gets the daily_duration_minutes of this CreateAdminTimeOffRequest.
        The daily duration of this time off request in minutes

        :return: The daily_duration_minutes of this CreateAdminTimeOffRequest.
        :rtype: int
        """
        return self._daily_duration_minutes

    @daily_duration_minutes.setter
    def daily_duration_minutes(self, daily_duration_minutes):
        """
        Sets the daily_duration_minutes of this CreateAdminTimeOffRequest.
        The daily duration of this time off request in minutes

        :param daily_duration_minutes: The daily_duration_minutes of this CreateAdminTimeOffRequest.
        :type: int
        """
        
        self._daily_duration_minutes = daily_duration_minutes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmHistoricalAdherenceResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmHistoricalAdherenceResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'download_url': 'str',
            'download_result': 'WfmHistoricalAdherenceResultWrapper',
            'download_urls': 'list[str]',
            'query_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'download_url': 'downloadUrl',
            'download_result': 'downloadResult',
            'download_urls': 'downloadUrls',
            'query_state': 'queryState'
        }

        self._id = None
        self._download_url = None
        self._download_result = None
        self._download_urls = None
        self._query_state = None

    @property
    def id(self):
        """
        Gets the id of this WfmHistoricalAdherenceResponse.
        The query ID to listen for

        :return: The id of this WfmHistoricalAdherenceResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WfmHistoricalAdherenceResponse.
        The query ID to listen for

        :param id: The id of this WfmHistoricalAdherenceResponse.
        :type: str
        """
        
        self._id = id

    @property
    def download_url(self):
        """
        Gets the download_url of this WfmHistoricalAdherenceResponse.
        Deprecated. Use downloadUrls instead.

        :return: The download_url of this WfmHistoricalAdherenceResponse.
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """
        Sets the download_url of this WfmHistoricalAdherenceResponse.
        Deprecated. Use downloadUrls instead.

        :param download_url: The download_url of this WfmHistoricalAdherenceResponse.
        :type: str
        """
        
        self._download_url = download_url

    @property
    def download_result(self):
        """
        Gets the download_result of this WfmHistoricalAdherenceResponse.
        Result will always come via downloadUrls; however the schema is included for documentation

        :return: The download_result of this WfmHistoricalAdherenceResponse.
        :rtype: WfmHistoricalAdherenceResultWrapper
        """
        return self._download_result

    @download_result.setter
    def download_result(self, download_result):
        """
        Sets the download_result of this WfmHistoricalAdherenceResponse.
        Result will always come via downloadUrls; however the schema is included for documentation

        :param download_result: The download_result of this WfmHistoricalAdherenceResponse.
        :type: WfmHistoricalAdherenceResultWrapper
        """
        
        self._download_result = download_result

    @property
    def download_urls(self):
        """
        Gets the download_urls of this WfmHistoricalAdherenceResponse.
        The uri list to GET the results of the Historical Adherence query. For notification purposes only

        :return: The download_urls of this WfmHistoricalAdherenceResponse.
        :rtype: list[str]
        """
        return self._download_urls

    @download_urls.setter
    def download_urls(self, download_urls):
        """
        Sets the download_urls of this WfmHistoricalAdherenceResponse.
        The uri list to GET the results of the Historical Adherence query. For notification purposes only

        :param download_urls: The download_urls of this WfmHistoricalAdherenceResponse.
        :type: list[str]
        """
        
        self._download_urls = download_urls

    @property
    def query_state(self):
        """
        Gets the query_state of this WfmHistoricalAdherenceResponse.
        The state of the adherence query

        :return: The query_state of this WfmHistoricalAdherenceResponse.
        :rtype: str
        """
        return self._query_state

    @query_state.setter
    def query_state(self, query_state):
        """
        Sets the query_state of this WfmHistoricalAdherenceResponse.
        The state of the adherence query

        :param query_state: The query_state of this WfmHistoricalAdherenceResponse.
        :type: str
        """
        allowed_values = ["Processing", "Complete", "Error"]
        if query_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for query_state -> " + query_state)
            self._query_state = "outdated_sdk_version"
        else:
            self._query_state = query_state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class HistoricalAdherenceExceptionInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HistoricalAdherenceExceptionInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_offset_seconds': 'int',
            'end_offset_seconds': 'int',
            'scheduled_activity_code_id': 'str',
            'scheduled_activity_category': 'str',
            'actual_activity_category': 'str',
            'system_presence': 'str',
            'routing_status': 'RoutingStatus',
            'impact': 'str',
            'secondary_presence_lookup_id': 'str'
        }

        self.attribute_map = {
            'start_offset_seconds': 'startOffsetSeconds',
            'end_offset_seconds': 'endOffsetSeconds',
            'scheduled_activity_code_id': 'scheduledActivityCodeId',
            'scheduled_activity_category': 'scheduledActivityCategory',
            'actual_activity_category': 'actualActivityCategory',
            'system_presence': 'systemPresence',
            'routing_status': 'routingStatus',
            'impact': 'impact',
            'secondary_presence_lookup_id': 'secondaryPresenceLookupId'
        }

        self._start_offset_seconds = None
        self._end_offset_seconds = None
        self._scheduled_activity_code_id = None
        self._scheduled_activity_category = None
        self._actual_activity_category = None
        self._system_presence = None
        self._routing_status = None
        self._impact = None
        self._secondary_presence_lookup_id = None

    @property
    def start_offset_seconds(self):
        """
        Gets the start_offset_seconds of this HistoricalAdherenceExceptionInfo.
        Exception start offset in seconds relative to query start time

        :return: The start_offset_seconds of this HistoricalAdherenceExceptionInfo.
        :rtype: int
        """
        return self._start_offset_seconds

    @start_offset_seconds.setter
    def start_offset_seconds(self, start_offset_seconds):
        """
        Sets the start_offset_seconds of this HistoricalAdherenceExceptionInfo.
        Exception start offset in seconds relative to query start time

        :param start_offset_seconds: The start_offset_seconds of this HistoricalAdherenceExceptionInfo.
        :type: int
        """
        
        self._start_offset_seconds = start_offset_seconds

    @property
    def end_offset_seconds(self):
        """
        Gets the end_offset_seconds of this HistoricalAdherenceExceptionInfo.
        Exception end offset in seconds relative to query start time

        :return: The end_offset_seconds of this HistoricalAdherenceExceptionInfo.
        :rtype: int
        """
        return self._end_offset_seconds

    @end_offset_seconds.setter
    def end_offset_seconds(self, end_offset_seconds):
        """
        Sets the end_offset_seconds of this HistoricalAdherenceExceptionInfo.
        Exception end offset in seconds relative to query start time

        :param end_offset_seconds: The end_offset_seconds of this HistoricalAdherenceExceptionInfo.
        :type: int
        """
        
        self._end_offset_seconds = end_offset_seconds

    @property
    def scheduled_activity_code_id(self):
        """
        Gets the scheduled_activity_code_id of this HistoricalAdherenceExceptionInfo.
        The ID of the scheduled activity for this user

        :return: The scheduled_activity_code_id of this HistoricalAdherenceExceptionInfo.
        :rtype: str
        """
        return self._scheduled_activity_code_id

    @scheduled_activity_code_id.setter
    def scheduled_activity_code_id(self, scheduled_activity_code_id):
        """
        Sets the scheduled_activity_code_id of this HistoricalAdherenceExceptionInfo.
        The ID of the scheduled activity for this user

        :param scheduled_activity_code_id: The scheduled_activity_code_id of this HistoricalAdherenceExceptionInfo.
        :type: str
        """
        
        self._scheduled_activity_code_id = scheduled_activity_code_id

    @property
    def scheduled_activity_category(self):
        """
        Gets the scheduled_activity_category of this HistoricalAdherenceExceptionInfo.
        Activity for which the user is scheduled

        :return: The scheduled_activity_category of this HistoricalAdherenceExceptionInfo.
        :rtype: str
        """
        return self._scheduled_activity_category

    @scheduled_activity_category.setter
    def scheduled_activity_category(self, scheduled_activity_category):
        """
        Sets the scheduled_activity_category of this HistoricalAdherenceExceptionInfo.
        Activity for which the user is scheduled

        :param scheduled_activity_category: The scheduled_activity_category of this HistoricalAdherenceExceptionInfo.
        :type: str
        """
        allowed_values = ["OnQueueWork", "Break", "Meal", "Meeting", "OffQueueWork", "TimeOff", "Training", "Unavailable", "Unscheduled"]
        if scheduled_activity_category.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for scheduled_activity_category -> " + scheduled_activity_category)
            self._scheduled_activity_category = "outdated_sdk_version"
        else:
            self._scheduled_activity_category = scheduled_activity_category

    @property
    def actual_activity_category(self):
        """
        Gets the actual_activity_category of this HistoricalAdherenceExceptionInfo.
        Activity for which the user is actually engaged

        :return: The actual_activity_category of this HistoricalAdherenceExceptionInfo.
        :rtype: str
        """
        return self._actual_activity_category

    @actual_activity_category.setter
    def actual_activity_category(self, actual_activity_category):
        """
        Sets the actual_activity_category of this HistoricalAdherenceExceptionInfo.
        Activity for which the user is actually engaged

        :param actual_activity_category: The actual_activity_category of this HistoricalAdherenceExceptionInfo.
        :type: str
        """
        allowed_values = ["OnQueueWork", "Break", "Meal", "Meeting", "OffQueueWork", "TimeOff", "Training", "Unavailable", "Unscheduled"]
        if actual_activity_category.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for actual_activity_category -> " + actual_activity_category)
            self._actual_activity_category = "outdated_sdk_version"
        else:
            self._actual_activity_category = actual_activity_category

    @property
    def system_presence(self):
        """
        Gets the system_presence of this HistoricalAdherenceExceptionInfo.
        Actual underlying system presence value

        :return: The system_presence of this HistoricalAdherenceExceptionInfo.
        :rtype: str
        """
        return self._system_presence

    @system_presence.setter
    def system_presence(self, system_presence):
        """
        Sets the system_presence of this HistoricalAdherenceExceptionInfo.
        Actual underlying system presence value

        :param system_presence: The system_presence of this HistoricalAdherenceExceptionInfo.
        :type: str
        """
        allowed_values = ["Available", "Away", "Busy", "Offline", "Idle", "OnQueue", "Meal", "Training", "Meeting", "Break"]
        if system_presence.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for system_presence -> " + system_presence)
            self._system_presence = "outdated_sdk_version"
        else:
            self._system_presence = system_presence

    @property
    def routing_status(self):
        """
        Gets the routing_status of this HistoricalAdherenceExceptionInfo.
        Actual underlying routing status, used to determine whether a user is actually in adherence when OnQueue

        :return: The routing_status of this HistoricalAdherenceExceptionInfo.
        :rtype: RoutingStatus
        """
        return self._routing_status

    @routing_status.setter
    def routing_status(self, routing_status):
        """
        Sets the routing_status of this HistoricalAdherenceExceptionInfo.
        Actual underlying routing status, used to determine whether a user is actually in adherence when OnQueue

        :param routing_status: The routing_status of this HistoricalAdherenceExceptionInfo.
        :type: RoutingStatus
        """
        
        self._routing_status = routing_status

    @property
    def impact(self):
        """
        Gets the impact of this HistoricalAdherenceExceptionInfo.
        The impact of the current adherence state for this user

        :return: The impact of this HistoricalAdherenceExceptionInfo.
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """
        Sets the impact of this HistoricalAdherenceExceptionInfo.
        The impact of the current adherence state for this user

        :param impact: The impact of this HistoricalAdherenceExceptionInfo.
        :type: str
        """
        allowed_values = ["Positive", "Negative", "Neutral", "Unknown"]
        if impact.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for impact -> " + impact)
            self._impact = "outdated_sdk_version"
        else:
            self._impact = impact

    @property
    def secondary_presence_lookup_id(self):
        """
        Gets the secondary_presence_lookup_id of this HistoricalAdherenceExceptionInfo.
        The lookup ID used to retrieve secondary status from map of lookup ID to corresponding secondary presence ID

        :return: The secondary_presence_lookup_id of this HistoricalAdherenceExceptionInfo.
        :rtype: str
        """
        return self._secondary_presence_lookup_id

    @secondary_presence_lookup_id.setter
    def secondary_presence_lookup_id(self, secondary_presence_lookup_id):
        """
        Sets the secondary_presence_lookup_id of this HistoricalAdherenceExceptionInfo.
        The lookup ID used to retrieve secondary status from map of lookup ID to corresponding secondary presence ID

        :param secondary_presence_lookup_id: The secondary_presence_lookup_id of this HistoricalAdherenceExceptionInfo.
        :type: str
        """
        
        self._secondary_presence_lookup_id = secondary_presence_lookup_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

